summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/nsc/util/ClassPath.scala
diff options
context:
space:
mode:
authorPaul Phillips <paulp@improving.org>2010-03-10 16:21:56 +0000
committerPaul Phillips <paulp@improving.org>2010-03-10 16:21:56 +0000
commit10bcc73badcbb46deb1b707e94af65f439f62b66 (patch)
tree7329556a2e34b887230a4715ad0422a50774a611 /src/compiler/scala/tools/nsc/util/ClassPath.scala
parent0f5c2696c82f0027ccc815a008aac5a5226ca3e7 (diff)
downloadscala-10bcc73badcbb46deb1b707e94af65f439f62b66.tar.gz
scala-10bcc73badcbb46deb1b707e94af65f439f62b66.tar.bz2
scala-10bcc73badcbb46deb1b707e94af65f439f62b66.zip
Some minor compiler support bits for my upcomin...
Some minor compiler support bits for my upcoming partest patch. No review.
Diffstat (limited to 'src/compiler/scala/tools/nsc/util/ClassPath.scala')
-rw-r--r--src/compiler/scala/tools/nsc/util/ClassPath.scala7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/compiler/scala/tools/nsc/util/ClassPath.scala b/src/compiler/scala/tools/nsc/util/ClassPath.scala
index cc737b9fbb..0560062bf1 100644
--- a/src/compiler/scala/tools/nsc/util/ClassPath.scala
+++ b/src/compiler/scala/tools/nsc/util/ClassPath.scala
@@ -79,8 +79,11 @@ object ClassPath {
/** Split the classpath, filter according to predicate, and reassemble. */
def filter(cp: String, p: String => Boolean): String = join(split(cp) filter p: _*)
- /** Split the classpath and map them into urls */
- def toURLs(cp: String): List[URL] = split(cp) map (x => Path(x).toAbsolute.toURL)
+ /** Split the classpath and map them into Paths */
+ def toPaths(cp: String): List[Path] = split(cp) map (x => Path(x).toAbsolute)
+
+ /** Split the classpath and map them into URLs */
+ def toURLs(cp: String): List[URL] = toPaths(cp) map (_.toURL)
/** Expand path and possibly expanding stars */
def expandPath(path: String, expandStar: Boolean = true): List[String] =